==> com.liferay.layout.content.page.editor.web-2.0.74.jar: META-INF/resources/page_editor/app/components/fragment-configuration-fields/ImageSelectorField.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.74/page_editor/app/components/fragment-configuration-fields/ImageSelectorField", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/form', 'frontend-js-react-web$prop-types', 'frontend-js-react-web$react', '../../../common/components/ImageSelector', '../../../common/components/MappingSelector', '../../../prop-types/index', '../../config/constants/editableTypes', '../../utils/useId'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.ImageSelectorField = void 0;

    var _form = _interopRequireWildcard(require("@frontend-taglib-clay$clayui/form"));

    var _propTypes = _interopRequireDefault(require("frontend-js-react-web$prop-types"));

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    var _ImageSelector = require("../../../common/components/ImageSelector");

    var _MappingSelector = _interopRequireDefault(require("../../../common/components/MappingSelector"));

    var _index = require("../../../prop-types/index");

    var _editableTypes = require("../../config/constants/editableTypes");

    var _useId = require("../../utils/useId");

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { "default": obj };
    }

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { "default": obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj["default"] = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _slicedToArray(arr, i) {
      return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
    }

    function _nonIterableRest() {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }

    function _iterableToArrayLimit(arr, i) {
      if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
        return;
      }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
        for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
          _arr.push(_s.value);if (i && _arr.length === i) break;
        }
      } catch (err) {
        _d = true;_e = err;
      } finally {
        try {
          if (!_n && _i["return"] != null) _i["return"]();
        } finally {
          if (_d) throw _e;
        }
      }return _arr;
    }

    function _arrayWithHoles(arr) {
      if (Array.isArray(arr)) return arr;
    }

    var IMAGE_SOURCES = {
      mapping: {
        label: Liferay.Language.get('content-mapping'),
        value: 'content_mapping'
      },
      selection: {
        label: Liferay.Language.get('manual-selection'),
        value: 'manual_selection'
      }
    };

    var ImageSelectorField = function ImageSelectorField(_ref) {
      var field = _ref.field,
          onValueSelect = _ref.onValueSelect,
          _ref$value = _ref.value,
          value = _ref$value === void 0 ? {} : _ref$value;
      var imageSourceInputId = (0, _useId.useId)();

      var _useState = (0, _react.useState)(function () {
        return value.fieldId || value.mappedField ? IMAGE_SOURCES.mapping.value : IMAGE_SOURCES.selection.value;
      }),
          _useState2 = _slicedToArray(_useState, 2),
          imageSource = _useState2[0],
          setImageSource = _useState2[1];

      var handleImageChanged = function handleImageChanged(image) {
        onValueSelect(field.name, image);
      };

      return _react["default"].createElement(_react["default"].Fragment, null, _react["default"].createElement(_form["default"].Group, {
        small: true
      }, _react["default"].createElement("label", {
        htmlFor: imageSourceInputId
      }, Liferay.Language.get('image-source')), _react["default"].createElement(_form.ClaySelectWithOption, {
        id: imageSourceInputId,
        onChange: function handleSourceChanged(event) {
          setImageSource(event.target.value);

          if (Object.keys(value).length) {
            handleImageChanged({});
          }
        },
        options: Object.values(IMAGE_SOURCES),
        value: imageSource
      })), imageSource === IMAGE_SOURCES.selection.value ? _react["default"].createElement(_ImageSelector.ImageSelector, {
        imageTitle: value.title,
        label: field.label,
        onClearButtonPressed: function onClearButtonPressed() {
          return handleImageChanged({});
        },
        onImageSelected: handleImageChanged
      }) : _react["default"].createElement(_MappingSelector["default"], {
        fieldType: _editableTypes.EDITABLE_TYPES.backgroundImage,
        mappedItem: value,
        onMappingSelect: handleImageChanged
      }));
    };

    exports.ImageSelectorField = ImageSelectorField;
    //# sourceMappingURL=ImageSelectorField.js.map
  }
});
//# sourceMappingURL=ImageSelectorField.js.map

==> com.liferay.layout.content.page.editor.web-2.0.122.jar: META-INF/resources/page_editor/app/components/fragment-configuration-fields/ImageSelectorField.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.122/page_editor/app/components/fragment-configuration-fields/ImageSelectorField", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/form', 'frontend-js-react-web$prop-types', 'frontend-js-react-web$react', '../../../common/components/ImageSelector', '../../../common/components/MappingSelector', '../../../prop-types/index', '../../config/constants/editableTypes', '../../utils/useId'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.ImageSelectorField = void 0;

    var _form = _interopRequireWildcard(require("@frontend-taglib-clay$clayui/form"));

    var _propTypes = _interopRequireDefault(require("frontend-js-react-web$prop-types"));

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    var _ImageSelector = require("../../../common/components/ImageSelector");

    var _MappingSelector = _interopRequireDefault(require("../../../common/components/MappingSelector"));

    var _index = require("../../../prop-types/index");

    var _editableTypes = require("../../config/constants/editableTypes");

    var _useId = require("../../utils/useId");

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { default: obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj.default = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _slicedToArray(arr, i) {
      return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
    }

    function _nonIterableRest() {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }

    function _iterableToArrayLimit(arr, i) {
      if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
        return;
      }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
        for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
          _arr.push(_s.value);if (i && _arr.length === i) break;
        }
      } catch (err) {
        _d = true;_e = err;
      } finally {
        try {
          if (!_n && _i["return"] != null) _i["return"]();
        } finally {
          if (_d) throw _e;
        }
      }return _arr;
    }

    function _arrayWithHoles(arr) {
      if (Array.isArray(arr)) return arr;
    }

    var IMAGE_SOURCES = {
      mapping: {
        label: Liferay.Language.get('content-mapping'),
        value: 'content_mapping'
      },
      selection: {
        label: Liferay.Language.get('manual-selection'),
        value: 'manual_selection'
      }
    };

    var ImageSelectorField = function ImageSelectorField(_ref) {
      var field = _ref.field,
          onValueSelect = _ref.onValueSelect,
          _ref$value = _ref.value,
          value = _ref$value === void 0 ? {} : _ref$value;
      var imageSourceInputId = (0, _useId.useId)();

      var _useState = (0, _react.useState)(function () {
        return value.fieldId || value.mappedField ? IMAGE_SOURCES.mapping.value : IMAGE_SOURCES.selection.value;
      }),
          _useState2 = _slicedToArray(_useState, 2),
          imageSource = _useState2[0],
          setImageSource = _useState2[1];

      var handleImageChanged = function handleImageChanged(image) {
        onValueSelect(field.name, image);
      };

      return (/*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_form.default.Group, {
          small: true
        }, /*#__PURE__*/_react.default.createElement("label", {
          htmlFor: imageSourceInputId
        }, Liferay.Language.get('image-source')), /*#__PURE__*/_react.default.createElement(_form.ClaySelectWithOption, {
          id: imageSourceInputId,
          onChange: function handleSourceChanged(event) {
            setImageSource(event.target.value);

            if (Object.keys(value).length) {
              handleImageChanged({});
            }
          },
          options: Object.values(IMAGE_SOURCES),
          value: imageSource
        })), imageSource === IMAGE_SOURCES.selection.value ? /*#__PURE__*/_react.default.createElement(_ImageSelector.ImageSelector, {
          imageTitle: value.title,
          label: field.label,
          onClearButtonPressed: function onClearButtonPressed() {
            return handleImageChanged({});
          },
          onImageSelected: handleImageChanged
        }) : /*#__PURE__*/_react.default.createElement(_MappingSelector.default, {
          fieldType: _editableTypes.EDITABLE_TYPES.backgroundImage,
          mappedItem: value,
          onMappingSelect: handleImageChanged
        }))
      );
    };

    exports.ImageSelectorField = ImageSelectorField;
    //# sourceMappingURL=ImageSelectorField.js.map
  }
});
//# sourceMappingURL=ImageSelectorField.js.map
